@@ -134,8 +134,6 @@ sub insert_schedule ($@) {
 	} map(ref $_ && ref $_ eq 'ARRAY' ? @{$_} : $_, @games);
 	$schedule_c->delete_many({_id => { '$in' => [ map {$_->{_id}} @games ] } });
 	$schedule_c->insert_many([@games]);
-	use Data::Dumper;
-	print Dumper \@games;
 	debug "Inserted " . scalar(@games) . " games for season $games[0]->{season}";
 	scalar @games;
 }
