@@ -15,6 +15,8 @@ our @EXPORT = qw(
 	%NAME_TYPOS %NAME_VARIATIONS %REVERSE_NAME_TYPOS
 	%SPECIAL_EVENTS %FORCED_PUSH
 	%MISSING_EVENTS %MISSING_COACHES %MISSING_PLAYERS
+
+	$INCOMPLETE $REPLICA $NO_EVENTS $UNSYNCHED $BROKEN
 );
 
 our %NAME_TYPOS = (
@@ -62,11 +64,16 @@ our %BROKEN_PLAYER_IDS = (8445204 => 8445202);
 
 our %BROKEN_PLAYERS = (
 	BS => {
-		192730312 => {
-			8448095 => { number => 16, }
-		},
+		192730312 => { 8448095 => { number => 16, }	},
+		196820129 => { 8449481 => { penaltyMinutes => 2,}},
+		197820329 => { 8446940 => { penaltyMinutes => 16,}},
+		198020400 => { 8448411 => { penaltyMinutes => 21,}},
+		198720798 => { 8449535 => { assists => 1, } },
+		199120753 => { 8448781 => { penaltyMinutes => 7 }},
+		199320074 => { 8455408 => { penaltyMinutes => 4 }},
+		199320640 => { 8455984 => { penaltyMinutes => 6 }},
 		200320009 => {
-			8467349 => { number => 8,  position => 'D', },
+			8467349 => { number => 8,  position => 'D', goals => 1, },
 			8468789 => { number => 29, position => 'C', },
 			8464960 => { number => 21, position => 'C', },
 		},
@@ -75,34 +82,46 @@ our %BROKEN_PLAYERS = (
 		},
 		200320019 => {
 			8466147 => { number => 17, position => 'C',},
-		}
+		},
+		200320104 => {
+			8467333 => { goals => 1, },
+		},
+		200320132 => {
+			8452578 => { number => 19, position => 'C', goals => 1},
+		},
+		200320248 => {
+			8468003 => {goals => 1,},
+		},
+		200320459 => {
+			8468083 => { goals => 1, assists => 2, number => 40 },
+		},
+		200820502 => { 8470201 => { penaltyMinutes => 2, }},
+		201520995 => { 8470602 => { penaltyMinutes => 6, }},
 	},
 );
 
 our %FORCED_PUSH = (
-        PL => {
-                200820009 => { 82  => 1, 83 => 1, },
-                201020989 => { 346 => 1 },
-                201120094 => { 198 => 1 },
-                201320083 => { 351 => 1 },
-                201420921 => { 354 => 1 },
-                201520057 => { 150 => 1, 158 => 1, 197 => 1 },
-                201520064 => { 316 => 1 },
-                201520436 => { 176 => 1 },
-                201520518 => { 152 => 1 },
-                201520593 => { 273 => 1 },
-                201520741 => { 343 => 1, 344 => 1 },
-                201521035 => { 172 => 1 },
-                201530122 => { 347 => 1 },
-                201620161 => { 286 => 1 },
-                201620177 => { 197 => 1 },
-                201620321 => {  64 => 1 },
-                201620920 => { 296 => 1, 297 => 1 },
-                #201621070 => {  35 => 1 },
-                201621081 => { 101 => 1 },
-                201720176 => { 303 => 1, 304 => 1, 305 => 1, 306 => 1},
-                #200820681 => {  74 => 1 },
-        },
+	PL => {
+		200820009 => { 82  => 1, 83 => 1, },
+		201020989 => { 346 => 1 },
+		201120094 => { 198 => 1 },
+		201320083 => { 351 => 1 },
+		201420921 => { 354 => 1 },
+		201520057 => { 150 => 1, 158 => 1, 197 => 1 },
+		201520064 => { 316 => 1 },
+		201520436 => { 176 => 1 },
+		201520518 => { 152 => 1 },
+		201520593 => { 273 => 1 },
+		201520741 => { 343 => 1, 344 => 1 },
+		201521035 => { 172 => 1 },
+		201530122 => { 347 => 1 },
+		201620161 => { 286 => 1 },
+		201620177 => { 197 => 1 },
+		201620321 => {  64 => 1 },
+		201620920 => { 296 => 1, 297 => 1 },
+		201621081 => { 101 => 1 },
+		201720176 => { 303 => 1, 304 => 1, 305 => 1, 306 => 1},
+	},
 );
 
 our %BROKEN_ROSTERS = (
@@ -127,8 +146,10 @@ our %BROKEN_ROSTERS = (
 	199620473 => [ [ { 'No.' => 27, penaltyMinutes => 2, }, ], [], ],
 	199620546 => [ [ { 'No.' => 17, penaltyMinutes => 2, }, ], [], ],
 	199620548 => [ [ { 'No.' => 33, penaltyMinutes => 23 }, ], [], ],
-	199620927 => [ [ { 'No.' => 20, penaltyMinutes => 2, },
-		{ 'No.' => 77, penaltyMinutes => 2, }, ], [], ],
+	199620927 => [ [
+		{ 'No.' => 20, penaltyMinutes => 2, },
+		{ 'No.' => 77, penaltyMinutes => 2, },
+	], [], ],
 	199630222 => [ [], [ { 'No.' => 18, penaltyMinutes => 2, }, ], ],
 	199720830 => [ [], [ { 'No.' => 35, 'EV' => '10 - 12' }, ], ],
 	199720876 => [ [], [ { 'No.' => 27, 'EV' => '11 - 14' }, ], ],
@@ -141,9 +162,18 @@ our %BROKEN_ROSTERS = (
 
 our %BROKEN_EVENTS = (
 	BS => {
+		195520195 => { 18 => { time => '10:06' },},
+		198320770 => {
+			20 => { time => '1:29' },
+			21 => { time => '1:29' },
+		},
 		198520010 => { 16 => { time =>  '7:48' }, },
 		198520611 => { 32 => { time => '10:09' }, },
 		198820689 => {  5 => { player2 => 8446637 }, 6 => { player2 => 8446637 }, },
+		198920567 => { 26 => { player1 => 8450167 }},
+		201021015 => { 345 => {en => 1}},
+		201621152 => { 9 => { assist2 => 8475209, assists => [8474141,8475209] }},
+		201621165 => { 43 => { player1 => 8465009, assists => [ 8478443, 8476374]}}
 	},
 	BH => {
 
@@ -156,18 +186,19 @@ our %BROKEN_EVENTS = (
 		},
 		200321115 => { 10 =>  { player2 => 38 } },
         200520084 => { 54  => { player1 => 35 } },
-#        200520094 => {   3 => { team1 => 'NYR', strength => 'EV', }, },
 		200520307 => { 176 => { player1 => 20 } },
 		200520312 => {
 			1 => {
-				id          => 1, period => 1, time => '0:00', team => 'NSH', strength => 'EV',
-				shot_type   => 'Snap', distance => 18, type => 'GOAL', location => 'Off',
+				id => 1, period => 1, time => '0:00', team => 'NSH',
+				strength => 'EV', shot_type   => 'Snap',
+				distance => 18, type => 'GOAL', location => 'Off',
 				description => '22 JOHNSON, A: 20 SUTER, 7 UPSHALL, Snap, 18 ft',
 				old         => 1, team1 => 'NSH', player1 => 22, assist1 => 20,
 				on_ice      => [ [], [], ], special => 1, stage => 2, season => 2005,
 			},
 		},
 		200520314 => {  47 => { player1 => 20 } },
+		200520472 => { 107 => { player1 => 23 }},
         200520473 => { 254 => 0, },
         200520511 => { 247 => 0 },
         200520873 => { 143 => 0 },
@@ -179,6 +210,7 @@ our %BROKEN_EVENTS = (
         200620637 => { 123 => 0, 217 => 0 },
         200620672 => { 131 => 0 },
         200620681 => { 305 => 0, },
+		200620698 => { 234 => { player1 => 27 }},
         200620765 => { 266 => 0, },
         200621005 => { 180 => 0, },
         200621019 => {  66 => 0, },
@@ -193,40 +225,40 @@ our %BROKEN_EVENTS = (
         200720026 => { 195 => { team1 => 'FLA', }, },
 		200720028 => { 269 => 0, },
         200720039 => {  21 => { team1 => 'CAR', }, },
-        200720199 => { 260 => 0, },
+		200720162 => { 281 => 0, },
+		200720199 => { 260 => 0, },
+		200720811 => { 344 => { on_ice2 => [ 35 ] }},
 		200730174 => {
 			221 => { on_ice => [ [15,25,6,33,41,29], [94,39,8,24,44,60] ]},
 			222 => { on_ice => [ [15,25,6,33,41,29], [94,39,8,24,44,60] ]},
 			223 => { on_ice => [ [15,25,6,33,41,29], [94,39,8,24,44,60] ]}
 		} ,
+        200820118 => { 4   => { winning_team => 'EDM', } },
+        200820332 => { 263 => { winning_team => 'DET', } },
+		200820444 => { 190 => { player1 => $UNKNOWN_PLAYER_ID } },
+        200820650 => { 37  => { winning_team => 'MIN', } },
+        200820749 => { 207 => { winning_team => 'TBL', } },
+        200820774 => { 92  => 0, 93 => {player1 => 17, }},
+		200820868 => { 299 => { length => 2, penalty => 'Instigator', description => 'EDM #18 MOREAU Instigator(2 min) Drawn By: DAL #29 OTT'}, },
+		200820900 => { 284 => { on_ice => [] }},
+        200820987 => { 284 => 0, },
+        200821191 => { 289 => { player1 => 20, team1 => 'NSH', player2 => 2, team2 => 'CHI' } },
 		200921066 => {
 			21 => { on_ice => [ [33,43,20,23,52,35], [17,38,40,3,29,1] ]},
 		},
-		201120110 => {
-			89 => { on_ice => [ [81,84,19,2,51,50], [27,48,17,41,35] ]},
-		},
-		201220341 => { 301 => 0, },
-		201321139 => {
-			13 => { on_ice => [ [51,89,57,19,84,30], [8,19,88,7,61,31] ]},
-		},
-		201521197 => {
-			27 => { on_ice => [ [ 21,10,15,5,6,1 ], [18,57,52,3,33,37] ] },
-		},
-		201621229 => {
-			178 => { on_ice => [[15,21,73,6,53,32], [50,10,2,53,1]]},
-		},
-#        201230174 => { 396 => { penalty => 'ABUSIVE LANGUAGE' } },
+        200921217 => { 138 => 0, },
         201020146 => { 311 => { player1 => 39, servedby => 26, }, },
-		200820444 => { 190 => { player1 => $UNKNOWN_PLAYER_ID } },
-		200820868 => { 299 => { length => 2, penalty => 'Instigator', description => 'EDM #18 MOREAU Instigator(2 min) Drawn By: DAL #29 OTT'}, },
-        200821191 => { 289 => { player1 => 20, team1 => 'NSH', player2 => 2, team2 => 'CHI', }, },
 		201020596 => { 275 => 0, },
 		201020989 => { 346 => { reason => 'GOALIE STOPPED', description => 'GOALIE STOPPED', }, },
         201120094 => { 198 => { reason => 'GOALIE STOPPED', description => 'GOALIE STOPPED', }, },
+		201120110 => {
+			89 => { on_ice => [ [81,84,19,2,51,50], [27,48,17,41,35] ]},
+		},
 		201120553 => { 294 => {
 			length => 10, penalty => 'Misconduct', misconduct => 1,
 			description => 'FLA #21 BARCH Game misconduct(10 min)',
 		} },
+		201220341 => { 301 => 0, },
 		201320971 => {   1 => {
 			id => 1, period => 1,
 			time => '0:00',
@@ -245,9 +277,18 @@ our %BROKEN_EVENTS = (
 			on_ice => [ [], [], ],
 			special => 1, en => 0, gwg => 0,
 		} },
+		201321139 => {
+			13 => { on_ice => [ [51,89,57,19,84,30], [8,19,88,7,61,31] ]},
+		},
         201420600 => { 328 => 0 },
         201420921 => { 354 => { reason => 'GOALIE STOPPED', description => 'GOALIE STOPPED', }, },
+		201521197 => {
+			27 => { on_ice => [ [ 21,10,15,5,6,1 ], [18,57,52,3,33,37] ] },
+		},
 		201621127 => { 311 => { description => 'BOS #55 ACCIARI Misconduct(10 min), Def. Zone' }},
+		201621229 => {
+			178 => { on_ice => [[15,21,73,6,53,32], [50,10,2,53,1]]},
+		},
 	},
 	GS => {
 	}
@@ -261,705 +302,81 @@ our %BROKEN_COORDS = (
 
 );
 
-my $INCOMPLETE = -1;
-my $REPLICA    = -2;
-my $BROKEN     = -3;
-my $NO_EVENTS  = -4;
+our $INCOMPLETE = -1;
+our $REPLICA    = -2;
+our $BROKEN     = -3;
+our $NO_EVENTS  = -4;
+our $UNSYNCHED  = -5;
 
 our %BROKEN_FILES = (
-	192130111 => { BS => $NO_EVENTS },
-	192220010 => { BS => $NO_EVENTS },
-	192620007 => { BS => $NO_EVENTS },
-	192620097 => { BS => $NO_EVENTS },
-	192620133 => { BS => $NO_EVENTS },
-	192620149 => { BS => $NO_EVENTS },
-	192720010 => { BS => $NO_EVENTS },
-	192720016 => { BS => $NO_EVENTS },
-	192720106 => { BS => $NO_EVENTS },
-	192820158 => { BS => $NO_EVENTS },
-	192920200 => { BS => $NO_EVENTS },
-	193020213 => { BS => $NO_EVENTS },
-	193120029 => { BS => $NO_EVENTS },
-	193120079 => { BS => $NO_EVENTS },
-	193120109 => { BS => $NO_EVENTS },
-	193220004 => { BS => $NO_EVENTS },
-	193220198 => { BS => $NO_EVENTS },
-	193330141 => { BS => $NO_EVENTS },
-	193520069 => { BS => $NO_EVENTS },
-	193520118 => { BS => $NO_EVENTS },
-	193720055 => { BS => $NO_EVENTS },
-	193720156 => { BS => $NO_EVENTS },
-	193820018 => { BS => $NO_EVENTS },
-	193820123 => { BS => $NO_EVENTS },
-	193920002 => { BS => $NO_EVENTS },
-	194220008 => { BS => $NO_EVENTS },
-	194220030 => { BS => $NO_EVENTS },
-	194220125 => { BS => $NO_EVENTS },
-	194320101 => { BS => $NO_EVENTS },
-	194320118 => { BS => $NO_EVENTS },
-	194420032 => { BS => $NO_EVENTS },
-	194420120 => { BS => $NO_EVENTS },
-	194430216 => { BS => $NO_EVENTS },
-	194620098 => { BS => $NO_EVENTS },
-	194620113 => { BS => $NO_EVENTS },
-	194620134 => { BS => $NO_EVENTS },
-	194720071 => { BS => $NO_EVENTS },
-	194720129 => { BS => $NO_EVENTS },
-	194730114 => { BS => $NO_EVENTS },
-	194820012 => { BS => $NO_EVENTS },
-	194820083 => { BS => $NO_EVENTS },
-	194920036 => { BS => $NO_EVENTS },
-	194920041 => { BS => $NO_EVENTS },
-	194920051 => { BS => $NO_EVENTS },
-	194920082 => { BS => $NO_EVENTS },
-	195020056 => { BS => $NO_EVENTS },
-	195020127 => { BS => $NO_EVENTS },
-	195120010 => { BS => $NO_EVENTS },
-	195120089 => { BS => $NO_EVENTS },
-	195220059 => { BS => $NO_EVENTS },
+	191730211 => { BS => $UNSYNCHED},
+	191730212 => { BS => $UNSYNCHED},
+	191730213 => { BS => $UNSYNCHED},
+	191730214 => { BS => $UNSYNCHED},
+	191730215 => { BS => $UNSYNCHED},
+	191830211 => { BS => $UNSYNCHED},
+	191830212 => { BS => $UNSYNCHED},
+	191830213 => { BS => $UNSYNCHED},
+	191830214 => { BS => $UNSYNCHED},
+	191830215 => { BS => $UNSYNCHED},
+	191930211 => { BS => $UNSYNCHED},
+	191930212 => { BS => $UNSYNCHED},
+	191930213 => { BS => $UNSYNCHED},
+	191930214 => { BS => $UNSYNCHED},
+	191930215 => { BS => $UNSYNCHED},
+	192130211 => { BS => $UNSYNCHED},
+	192130212 => { BS => $UNSYNCHED},
+	192130213 => { BS => $UNSYNCHED},
+	192130214 => { BS => $UNSYNCHED},
+	192130215 => { BS => $UNSYNCHED},
+	192430311 => { BS => $UNSYNCHED},
+	192430312 => { BS => $UNSYNCHED},
+	192430313 => { BS => $UNSYNCHED},
+	192430314 => { BS => $UNSYNCHED},
+	192530311 => { BS => $UNSYNCHED},
+	192530312 => { BS => $UNSYNCHED},
+	192530313 => { BS => $UNSYNCHED},
+	192530314 => { BS => $UNSYNCHED},
 	195220105 => { BS => $NO_EVENTS },
-	195220140 => { BS => $NO_EVENTS },
-	195220150 => { BS => $NO_EVENTS },
-	195220164 => { BS => $NO_EVENTS },
-	195230111 => { BS => $NO_EVENTS },
 	195320012 => { BS => $NO_EVENTS },
-	195320086 => { BS => $NO_EVENTS },
-	195320148 => { BS => $NO_EVENTS },
-	195320192 => { BS => $NO_EVENTS },
-	195420046 => { BS => $NO_EVENTS },
-	195420049 => { BS => $NO_EVENTS },
-	195420151 => { BS => $NO_EVENTS },
-	195420188 => { BS => $NO_EVENTS },
-	195430111 => { BS => $NO_EVENTS },
-	195520193 => { BS => $NO_EVENTS },
-	195620013 => { BS => $NO_EVENTS },
-	195720005 => { BS => $NO_EVENTS },
-	195820192 => { BS => $NO_EVENTS },
-	195920058 => { BS => $NO_EVENTS },
-	195920071 => { BS => $NO_EVENTS },
-	195920182 => { BS => $NO_EVENTS },
-	195920202 => { BS => $NO_EVENTS },
-	196020094 => { BS => $NO_EVENTS },
-	196020139 => { BS => $NO_EVENTS },
-	196120106 => { BS => $NO_EVENTS },
-	196120137 => { BS => $NO_EVENTS },
-	196130212 => { BS => $NO_EVENTS },
-	196220204 => { BS => $NO_EVENTS },
+	195620210 => { BS => $UNSYNCHED},
+	195820138 => { BS => $UNSYNCHED},
 	196320003 => { BS => $NO_EVENTS },
-	196320089 => { BS => $NO_EVENTS },
-	196320186 => { BS => $NO_EVENTS },
-	196320195 => { BS => $NO_EVENTS },
-	196420180 => { BS => $NO_EVENTS },
-	196520131 => { BS => $NO_EVENTS },
-	196520165 => { BS => $NO_EVENTS },
-	196520189 => { BS => $NO_EVENTS },
-	196620020 => { BS => $NO_EVENTS },
-	196620095 => { BS => $NO_EVENTS },
-	196620107 => { BS => $NO_EVENTS },
-	196720019 => { BS => $NO_EVENTS },
-	196720076 => { BS => $NO_EVENTS },
-	196720183 => { BS => $NO_EVENTS },
-	196720226 => { BS => $NO_EVENTS },
 	196720356 => { BS => $NO_EVENTS },
-	196720405 => { BS => $NO_EVENTS },
-	196720437 => { BS => $NO_EVENTS },
-	196820115 => { BS => $NO_EVENTS },
-	196820127 => { BS => $NO_EVENTS },
-	196820143 => { BS => $NO_EVENTS },
-	196820158 => { BS => $NO_EVENTS },
-	196820167 => { BS => $NO_EVENTS },
-	196820189 => { BS => $NO_EVENTS },
-	196820214 => { BS => $NO_EVENTS },
-	196820315 => { BS => $NO_EVENTS },
-	196820404 => { BS => $NO_EVENTS },
-	196820425 => { BS => $NO_EVENTS },
-	196820440 => { BS => $NO_EVENTS },
-	196920012 => { BS => $NO_EVENTS },
-	196920060 => { BS => $NO_EVENTS },
-	196920121 => { BS => $NO_EVENTS },
-	196920209 => { BS => $NO_EVENTS },
-	196920314 => { BS => $NO_EVENTS },
-	196920331 => { BS => $NO_EVENTS },
-	196920390 => { BS => $NO_EVENTS },
-	196920422 => { BS => $NO_EVENTS },
-	196920432 => { BS => $NO_EVENTS },
-	196920455 => { BS => $NO_EVENTS },
-	197020112 => { BS => $NO_EVENTS },
-	197020173 => { BS => $NO_EVENTS },
-	197020245 => { BS => $NO_EVENTS },
-	197020254 => { BS => $NO_EVENTS },
-	197020365 => { BS => $NO_EVENTS },
-	197020396 => { BS => $NO_EVENTS },
-	197020506 => { BS => $NO_EVENTS },
-	197020539 => { BS => $NO_EVENTS },
-	197120017 => { BS => $NO_EVENTS },
-	197120073 => { BS => $NO_EVENTS },
-	197120076 => { BS => $NO_EVENTS },
-	197120210 => { BS => $NO_EVENTS },
-	197120275 => { BS => $NO_EVENTS },
-	197120310 => { BS => $NO_EVENTS },
-	197120326 => { BS => $NO_EVENTS },
-	197120345 => { BS => $NO_EVENTS },
-	197120446 => { BS => $NO_EVENTS },
-	197120456 => { BS => $NO_EVENTS },
-	197220106 => { BS => $NO_EVENTS },
-	197220135 => { BS => $NO_EVENTS },
-	197220179 => { BS => $NO_EVENTS },
-	197220213 => { BS => $NO_EVENTS },
-	197220281 => { BS => $NO_EVENTS },
-	197220305 => { BS => $NO_EVENTS },
-	197220324 => { BS => $NO_EVENTS },
-	197220361 => { BS => $NO_EVENTS },
-	197220368 => { BS => $NO_EVENTS },
-	197220413 => { BS => $NO_EVENTS },
-	197220566 => { BS => $NO_EVENTS },
-	197220568 => { BS => $NO_EVENTS },
-	197220587 => { BS => $NO_EVENTS },
-	197320034 => { BS => $NO_EVENTS },
-	197320039 => { BS => $NO_EVENTS },
-	197320080 => { BS => $NO_EVENTS },
-	197320134 => { BS => $NO_EVENTS },
-	197320148 => { BS => $NO_EVENTS },
-	197320165 => { BS => $NO_EVENTS },
-	197320170 => { BS => $NO_EVENTS },
-	197320174 => { BS => $NO_EVENTS },
-	197320195 => { BS => $NO_EVENTS },
-	197320245 => { BS => $NO_EVENTS },
-	197320259 => { BS => $NO_EVENTS },
-	197320266 => { BS => $NO_EVENTS },
-	197320298 => { BS => $NO_EVENTS },
-	197320322 => { BS => $NO_EVENTS },
-	197320339 => { BS => $NO_EVENTS },
-	197320351 => { BS => $NO_EVENTS },
-	197320411 => { BS => $NO_EVENTS },
-	197320478 => { BS => $NO_EVENTS },
-	197320483 => { BS => $NO_EVENTS },
-	197320490 => { BS => $NO_EVENTS },
-	197320514 => { BS => $NO_EVENTS },
 	197320520 => { BS => $NO_EVENTS },
-	197320590 => { BS => $NO_EVENTS },
-	197320593 => { BS => $NO_EVENTS },
-	197320619 => { BS => $NO_EVENTS },
-	197420040 => { BS => $NO_EVENTS },
-	197420193 => { BS => $NO_EVENTS },
-	197420205 => { BS => $NO_EVENTS },
-	197420244 => { BS => $NO_EVENTS },
-	197420283 => { BS => $NO_EVENTS },
-	197420296 => { BS => $NO_EVENTS },
-	197420314 => { BS => $NO_EVENTS },
-	197420396 => { BS => $NO_EVENTS },
-	197420421 => { BS => $NO_EVENTS },
-	197420517 => { BS => $NO_EVENTS },
-	197420522 => { BS => $NO_EVENTS },
-	197420602 => { BS => $NO_EVENTS },
-	197420641 => { BS => $NO_EVENTS },
-	197520033 => { BS => $NO_EVENTS },
-	197520051 => { BS => $NO_EVENTS },
-	197520057 => { BS => $NO_EVENTS },
-	197520110 => { BS => $NO_EVENTS },
 	197520138 => { BS => $NO_EVENTS },
-	197520181 => { BS => $NO_EVENTS },
-	197520224 => { BS => $NO_EVENTS },
-	197520233 => { BS => $NO_EVENTS },
-	197520261 => { BS => $NO_EVENTS },
-	197520263 => { BS => $NO_EVENTS },
-	197520322 => { BS => $NO_EVENTS },
-	197520329 => { BS => $NO_EVENTS },
 	197520379 => { BS => $NO_EVENTS },
-	197520382 => { BS => $NO_EVENTS },
-	197520452 => { BS => $NO_EVENTS },
-	197520492 => { BS => $NO_EVENTS },
-	197520501 => { BS => $NO_EVENTS },
-	197520568 => { BS => $NO_EVENTS },
-	197520639 => { BS => $NO_EVENTS },
-	197520671 => { BS => $NO_EVENTS },
-	197520673 => { BS => $NO_EVENTS },
-	197520680 => { BS => $NO_EVENTS },
-	197520692 => { BS => $NO_EVENTS },
-	197520718 => { BS => $NO_EVENTS },
-	197530112 => { BS => $NO_EVENTS },
-	197620008 => { BS => $NO_EVENTS },
 	197620012 => { BS => $NO_EVENTS },
-	197620071 => { BS => $NO_EVENTS },
-	197620076 => { BS => $NO_EVENTS },
-	197620154 => { BS => $NO_EVENTS },
-	197620245 => { BS => $NO_EVENTS },
-	197620378 => { BS => $NO_EVENTS },
-	197620385 => { BS => $NO_EVENTS },
-	197620511 => { BS => $NO_EVENTS },
-	197620548 => { BS => $NO_EVENTS },
-	197620564 => { BS => $NO_EVENTS },
-	197620640 => { BS => $NO_EVENTS },
-	197620707 => { BS => $NO_EVENTS },
-	197720007 => { BS => $NO_EVENTS },
 	197720070 => { BS => $NO_EVENTS },
-	197720106 => { BS => $NO_EVENTS },
-	197720132 => { BS => $NO_EVENTS },
-	197720214 => { BS => $NO_EVENTS },
-	197720276 => { BS => $NO_EVENTS },
-	197720385 => { BS => $NO_EVENTS },
-	197720418 => { BS => $NO_EVENTS },
-	197720423 => { BS => $NO_EVENTS },
 	197720469 => { BS => $NO_EVENTS },
-	197720511 => { BS => $NO_EVENTS },
-	197720582 => { BS => $NO_EVENTS },
-	197730323 => { BS => $NO_EVENTS },
-	197820012 => { BS => $NO_EVENTS },
-	197820088 => { BS => $NO_EVENTS },
-	197820114 => { BS => $NO_EVENTS },
-	197820117 => { BS => $NO_EVENTS },
-	197820296 => { BS => $NO_EVENTS },
-	197820334 => { BS => $NO_EVENTS },
-	197820344 => { BS => $NO_EVENTS },
-	197820354 => { BS => $NO_EVENTS },
-	197820486 => { BS => $NO_EVENTS },
-	197820513 => { BS => $NO_EVENTS },
-	197820544 => { BS => $NO_EVENTS },
-	197820550 => { BS => $NO_EVENTS },
 	197820577 => { BS => $NO_EVENTS },
-	197830322 => { BS => $NO_EVENTS },
-	197920152 => { BS => $NO_EVENTS },
 	197920370 => { BS => $NO_EVENTS },
-	197920374 => { BS => $NO_EVENTS },
-	197920483 => { BS => $NO_EVENTS },
 	197920492 => { BS => $NO_EVENTS },
-	197920507 => { BS => $NO_EVENTS },
-	197920593 => { BS => $NO_EVENTS },
-	197920625 => { BS => $NO_EVENTS },
-	197920630 => { BS => $NO_EVENTS },
-	197920686 => { BS => $NO_EVENTS },
-	197920711 => { BS => $NO_EVENTS },
-	197920738 => { BS => $NO_EVENTS },
-	197920744 => { BS => $NO_EVENTS },
-	197920831 => { BS => $NO_EVENTS },
-	197930162 => { BS => $NO_EVENTS },
-	198020020 => { BS => $NO_EVENTS },
-	198020042 => { BS => $NO_EVENTS },
-	198020095 => { BS => $NO_EVENTS },
-	198020174 => { BS => $NO_EVENTS },
-	198020179 => { BS => $NO_EVENTS },
-	198020202 => { BS => $NO_EVENTS },
-	198020254 => { BS => $NO_EVENTS },
-	198020273 => { BS => $NO_EVENTS },
-	198020294 => { BS => $NO_EVENTS },
-	198020417 => { BS => $NO_EVENTS },
-	198020516 => { BS => $NO_EVENTS },
-	198020518 => { BS => $NO_EVENTS },
-	198020531 => { BS => $NO_EVENTS },
-	198020598 => { BS => $NO_EVENTS },
-	198020674 => { BS => $NO_EVENTS },
-	198020719 => { BS => $NO_EVENTS },
-	198020764 => { BS => $NO_EVENTS },
-	198120013 => { BS => $NO_EVENTS },
-	198120167 => { BS => $NO_EVENTS },
-	198120221 => { BS => $NO_EVENTS },
-	198120281 => { BS => $NO_EVENTS },
-	198120339 => { BS => $NO_EVENTS },
-	198120375 => { BS => $NO_EVENTS },
-	198120399 => { BS => $NO_EVENTS },
-	198120429 => { BS => $NO_EVENTS },
-	198120526 => { BS => $NO_EVENTS },
-	198120559 => { BS => $NO_EVENTS },
-	198120608 => { BS => $NO_EVENTS },
-	198120610 => { BS => $NO_EVENTS },
-	198120693 => { BS => $NO_EVENTS },
-	198120739 => { BS => $NO_EVENTS },
-	198120742 => { BS => $NO_EVENTS },
 	198220019 => { BS => $NO_EVENTS },
-	198220145 => { BS => $NO_EVENTS },
-	198220266 => { BS => $NO_EVENTS },
-	198220290 => { BS => $NO_EVENTS },
-	198220308 => { BS => $NO_EVENTS },
-	198220333 => { BS => $NO_EVENTS },
-	198220365 => { BS => $NO_EVENTS },
-	198220464 => { BS => $NO_EVENTS },
-	198220487 => { BS => $NO_EVENTS },
-	198220517 => { BS => $NO_EVENTS },
-	198220577 => { BS => $NO_EVENTS },
-	198220641 => { BS => $NO_EVENTS },
-	198220729 => { BS => $NO_EVENTS },
-	198220831 => { BS => $NO_EVENTS },
-	198220840 => { BS => $NO_EVENTS },
-	198230123 => { BS => $NO_EVENTS },
-	198230213 => { BS => $NO_EVENTS },
-	198320019 => { BS => $NO_EVENTS },
-	198320056 => { BS => $NO_EVENTS },
-	198320066 => { BS => $NO_EVENTS },
-	198320144 => { BS => $NO_EVENTS },
-	198320198 => { BS => $NO_EVENTS },
-	198320212 => { BS => $NO_EVENTS },
-	198320215 => { BS => $NO_EVENTS },
-	198320232 => { BS => $NO_EVENTS },
-	198320285 => { BS => $NO_EVENTS },
-	198320336 => { BS => $NO_EVENTS },
-	198320386 => { BS => $NO_EVENTS },
-	198320493 => { BS => $NO_EVENTS },
-	198320517 => { BS => $NO_EVENTS },
-	198320588 => { BS => $NO_EVENTS },
-	198320607 => { BS => $NO_EVENTS },
-	198320792 => { BS => $NO_EVENTS },
-	198320797 => { BS => $NO_EVENTS },
-	198330134 => { BS => $NO_EVENTS },
-	198420035 => { BS => $NO_EVENTS },
-	198420160 => { BS => $NO_EVENTS },
-	198420196 => { BS => $NO_EVENTS },
-	198420245 => { BS => $NO_EVENTS },
-	198420307 => { BS => $NO_EVENTS },
-	198420404 => { BS => $NO_EVENTS },
-	198420415 => { BS => $NO_EVENTS },
-	198420427 => { BS => $NO_EVENTS },
-	198420608 => { BS => $NO_EVENTS },
-	198420743 => { BS => $NO_EVENTS },
-	198420761 => { BS => $NO_EVENTS },
-	198430182 => { BS => $NO_EVENTS },
-	198520175 => { BS => $NO_EVENTS },
-	198520249 => { BS => $NO_EVENTS },
-	198520255 => { BS => $NO_EVENTS },
-	198520292 => { BS => $NO_EVENTS },
-	198520367 => { BS => $NO_EVENTS },
 	198520534 => { BS => $NO_EVENTS },
-	198520558 => { BS => $NO_EVENTS },
-	198520574 => { BS => $NO_EVENTS },
-	198520575 => { BS => $NO_EVENTS },
 	198520592 => { BS => $NO_EVENTS },
-	198520603 => { BS => $NO_EVENTS },
-	198520626 => { BS => $NO_EVENTS },
-	198520649 => { BS => $NO_EVENTS },
-	198520654 => { BS => $NO_EVENTS },
-	198520680 => { BS => $NO_EVENTS },
-	198520719 => { BS => $NO_EVENTS },
-	198520778 => { BS => $NO_EVENTS },
-	198520834 => { BS => $NO_EVENTS },
-	198520835 => { BS => $NO_EVENTS },
-	198530131 => { BS => $NO_EVENTS },
-	198620039 => { BS => $NO_EVENTS },
-	198620050 => { BS => $NO_EVENTS },
-	198620082 => { BS => $NO_EVENTS },
 	198620125 => { BS => $NO_EVENTS },
-	198620127 => { BS => $NO_EVENTS },
-	198620145 => { BS => $NO_EVENTS },
-	198620154 => { BS => $NO_EVENTS },
 	198620163 => { BS => $NO_EVENTS },
-	198620247 => { BS => $NO_EVENTS },
-	198620264 => { BS => $NO_EVENTS },
-	198620280 => { BS => $NO_EVENTS },
-	198620387 => { BS => $NO_EVENTS },
-	198620402 => { BS => $NO_EVENTS },
-	198620444 => { BS => $NO_EVENTS },
-	198620481 => { BS => $NO_EVENTS },
-	198620542 => { BS => $NO_EVENTS },
-	198620547 => { BS => $NO_EVENTS },
-	198620561 => { BS => $NO_EVENTS },
-	198620568 => { BS => $NO_EVENTS },
-	198620577 => { BS => $NO_EVENTS },
-	198620743 => { BS => $NO_EVENTS },
 	198630152 => { BS => $NO_EVENTS },
-	198630223 => { BS => $NO_EVENTS },
-	198630411 => { BS => $NO_EVENTS },
-	198720020 => { BS => $NO_EVENTS },
-	198720054 => { BS => $NO_EVENTS },
-	198720089 => { BS => $NO_EVENTS },
-	198720137 => { BS => $NO_EVENTS },
-	198720184 => { BS => $NO_EVENTS },
-	198720221 => { BS => $NO_EVENTS },
-	198720264 => { BS => $NO_EVENTS },
-	198720271 => { BS => $NO_EVENTS },
-	198720326 => { BS => $NO_EVENTS },
-	198720360 => { BS => $NO_EVENTS },
-	198720379 => { BS => $NO_EVENTS },
-	198720399 => { BS => $NO_EVENTS },
-	198720508 => { BS => $NO_EVENTS },
-	198720550 => { BS => $NO_EVENTS },
-	198720589 => { BS => $NO_EVENTS },
-	198720590 => { BS => $NO_EVENTS },
-	198720608 => { BS => $NO_EVENTS },
-	198720636 => { BS => $NO_EVENTS },
-	198720659 => { BS => $NO_EVENTS },
-	198720690 => { BS => $NO_EVENTS },
-	198720711 => { BS => $NO_EVENTS },
-	198720720 => { BS => $NO_EVENTS },
-	198720722 => { BS => $NO_EVENTS },
-	198720730 => { BS => $NO_EVENTS },
-	198720793 => { BS => $NO_EVENTS },
-	198730121 => { BS => $NO_EVENTS },
-	198730244 => { BS => $NO_EVENTS },
-	198730314 => { BS => $NO_EVENTS },
-	198730413 => { BS => $NO_EVENTS },
-	198820001 => { BS => $NO_EVENTS },
-	198820049 => { BS => $NO_EVENTS },
-	198820061 => { BS => $NO_EVENTS },
-	198820106 => { BS => $NO_EVENTS },
-	198820109 => { BS => $NO_EVENTS },
-	198820205 => { BS => $NO_EVENTS },
-	198820209 => { BS => $NO_EVENTS },
-	198820247 => { BS => $NO_EVENTS },
-	198820254 => { BS => $NO_EVENTS },
-	198820301 => { BS => $NO_EVENTS },
-	198820353 => { BS => $NO_EVENTS },
-	198820467 => { BS => $NO_EVENTS },
-	198820543 => { BS => $NO_EVENTS },
-	198820637 => { BS => $NO_EVENTS },
-	198820690 => { BS => $NO_EVENTS },
-	198820742 => { BS => $NO_EVENTS },
-	198820781 => { BS => $NO_EVENTS },
-	198830215 => { BS => $NO_EVENTS },
-	198920042 => { BS => $NO_EVENTS },
-	198920072 => { BS => $NO_EVENTS },
-	198920110 => { BS => $NO_EVENTS },
-	198920187 => { BS => $NO_EVENTS },
-	198920271 => { BS => $NO_EVENTS },
-	198920347 => { BS => $NO_EVENTS },
-	198920435 => { BS => $NO_EVENTS },
-	198920506 => { BS => $NO_EVENTS },
-	198920508 => { BS => $NO_EVENTS },
-	198920520 => { BS => $NO_EVENTS },
-	198920567 => { BS => $NO_EVENTS },
-	198920608 => { BS => $NO_EVENTS },
-	198920665 => { BS => $NO_EVENTS },
-	198920689 => { BS => $NO_EVENTS },
-	198920707 => { BS => $NO_EVENTS },
-	198920731 => { BS => $NO_EVENTS },
-	198920778 => { BS => $NO_EVENTS },
-	198920801 => { BS => $NO_EVENTS },
-	198930121 => { BS => $NO_EVENTS },
-	198930174 => { BS => $NO_EVENTS },
-	199020019 => { BS => $NO_EVENTS },
-	199020031 => { BS => $NO_EVENTS },
-	199020061 => { BS => $NO_EVENTS },
-	199020074 => { BS => $NO_EVENTS },
 	199020225 => { BS => $NO_EVENTS },
-	199020304 => { BS => $NO_EVENTS },
-	199020355 => { BS => $NO_EVENTS },
-	199020398 => { BS => $NO_EVENTS },
-	199020408 => { BS => $NO_EVENTS },
-	199020413 => { BS => $NO_EVENTS },
-	199020456 => { BS => $NO_EVENTS },
-	199020549 => { BS => $NO_EVENTS },
-	199020555 => { BS => $NO_EVENTS },
-	199020615 => { BS => $NO_EVENTS },
-	199020621 => { BS => $NO_EVENTS },
 	199020623 => { BS => $NO_EVENTS },
-	199020762 => { BS => $NO_EVENTS },
-	199020813 => { BS => $NO_EVENTS },
-	199030136 => { BS => $NO_EVENTS },
-	199030172 => { BS => $NO_EVENTS },
-	199030187 => { BS => $NO_EVENTS },
-	199030413 => { BS => $NO_EVENTS },
-	199120040 => { BS => $NO_EVENTS },
-	199120053 => { BS => $NO_EVENTS },
-	199120167 => { BS => $NO_EVENTS },
-	199120228 => { BS => $NO_EVENTS },
-	199120321 => { BS => $NO_EVENTS },
-	199120416 => { BS => $NO_EVENTS },
-	199120437 => { BS => $NO_EVENTS },
-	199120444 => { BS => $NO_EVENTS },
-	199120492 => { BS => $NO_EVENTS },
-	199120499 => { BS => $NO_EVENTS },
-	199120593 => { BS => $NO_EVENTS },
 	199120627 => { BS => $NO_EVENTS },
-	199120667 => { BS => $NO_EVENTS },
-	199120708 => { BS => $NO_EVENTS },
-	199120716 => { BS => $NO_EVENTS },
-	199120759 => { BS => $NO_EVENTS },
-	199120830 => { BS => $NO_EVENTS },
-	199120850 => { BS => $NO_EVENTS },
-	199130142 => { BS => $NO_EVENTS },
-	199130246 => { BS => $NO_EVENTS },
 	199220004 => { BS => $NO_EVENTS },
 	199220082 => { BS => $NO_EVENTS },
-	199220089 => { BS => $NO_EVENTS },
-	199220125 => { BS => $NO_EVENTS },
-	199220149 => { BS => $NO_EVENTS },
-	199220206 => { BS => $NO_EVENTS },
-	199220207 => { BS => $NO_EVENTS },
-	199220213 => { BS => $NO_EVENTS },
 	199220242 => { BS => $NO_EVENTS },
-	199220362 => { BS => $NO_EVENTS },
-	199220366 => { BS => $NO_EVENTS },
-	199220412 => { BS => $NO_EVENTS },
-	199220421 => { BS => $NO_EVENTS },
-	199220475 => { BS => $NO_EVENTS },
-	199220493 => { BS => $NO_EVENTS },
-	199220511 => { BS => $NO_EVENTS },
-	199220512 => { BS => $NO_EVENTS },
-	199220516 => { BS => $NO_EVENTS },
-	199220525 => { BS => $NO_EVENTS },
-	199220611 => { BS => $NO_EVENTS },
-	199220646 => { BS => $NO_EVENTS },
-	199220656 => { BS => $NO_EVENTS },
-	199220689 => { BS => $NO_EVENTS },
-	199220722 => { BS => $NO_EVENTS },
-	199220739 => { BS => $NO_EVENTS },
-	199220798 => { BS => $NO_EVENTS },
-	199220805 => { BS => $NO_EVENTS },
-	199220823 => { BS => $NO_EVENTS },
-	199220851 => { BS => $NO_EVENTS },
-	199220920 => { BS => $NO_EVENTS },
-	199220940 => { BS => $NO_EVENTS },
-	199220963 => { BS => $NO_EVENTS },
-	199220971 => { BS => $NO_EVENTS },
-	199230125 => { BS => $NO_EVENTS },
-	199230163 => { BS => $NO_EVENTS },
-	199230182 => { BS => $NO_EVENTS },
-	199230413 => { BS => $NO_EVENTS },
-	199320155 => { BS => $NO_EVENTS },
-	199320213 => { BS => $NO_EVENTS },
-	199320223 => { BS => $NO_EVENTS },
-	199320255 => { BS => $NO_EVENTS },
-	199320278 => { BS => $NO_EVENTS },
-	199320294 => { BS => $NO_EVENTS },
-	199320317 => { BS => $NO_EVENTS },
-	199320337 => { BS => $NO_EVENTS },
-	199320383 => { BS => $NO_EVENTS },
-	199320418 => { BS => $NO_EVENTS },
-	199320434 => { BS => $NO_EVENTS },
-	199320526 => { BS => $NO_EVENTS },
 	199320538 => { BS => $NO_EVENTS },
-	199320598 => { BS => $NO_EVENTS },
-	199320599 => { BS => $NO_EVENTS },
-	199320607 => { BS => $NO_EVENTS },
-	199320646 => { BS => $NO_EVENTS },
-	199320658 => { BS => $NO_EVENTS },
-	199320680 => { BS => $NO_EVENTS },
-	199320721 => { BS => $NO_EVENTS },
-	199320740 => { BS => $NO_EVENTS },
-	199320801 => { BS => $NO_EVENTS },
-	199320806 => { BS => $NO_EVENTS },
-	199320839 => { BS => $NO_EVENTS },
-	199320949 => { BS => $NO_EVENTS },
-	199320968 => { BS => $NO_EVENTS },
-	199321001 => { BS => $NO_EVENTS },
-	199321013 => { BS => $NO_EVENTS },
-	199321034 => { BS => $NO_EVENTS },
-	199321057 => { BS => $NO_EVENTS },
-	199321081 => { BS => $NO_EVENTS },
-	199330147 => { BS => $NO_EVENTS },
-	199330151 => { BS => $NO_EVENTS },
-	199330181 => { BS => $NO_EVENTS },
-	199330231 => { BS => $NO_EVENTS },
-	199420005 => { BS => $NO_EVENTS },
-	199420043 => { BS => $NO_EVENTS },
-	199420125 => { BS => $NO_EVENTS },
-	199420127 => { BS => $NO_EVENTS },
-	199420186 => { BS => $NO_EVENTS },
-	199420189 => { BS => $NO_EVENTS },
-	199420199 => { BS => $NO_EVENTS },
-	199420208 => { BS => $NO_EVENTS },
-	199420217 => { BS => $NO_EVENTS },
-	199420288 => { BS => $NO_EVENTS },
-	199420353 => { BS => $NO_EVENTS },
-	199420510 => { BS => $NO_EVENTS },
-	199420571 => { BS => $NO_EVENTS },
-	199430211 => { BS => $NO_EVENTS },
-	199430231 => { BS => $NO_EVENTS },
-	199520006 => { BS => $NO_EVENTS },
-	199520015 => { BS => $NO_EVENTS },
-	199520060 => { BS => $NO_EVENTS },
 	199520135 => { BS => $NO_EVENTS },
-	199520136 => { BS => $NO_EVENTS },
-	199520207 => { BS => $NO_EVENTS },
-	199520298 => { BS => $NO_EVENTS },
-	199520318 => { BS => $NO_EVENTS },
-	199520385 => { BS => $NO_EVENTS },
-	199520400 => { BS => $NO_EVENTS },
-	199520406 => { BS => $NO_EVENTS },
-	199520494 => { BS => $NO_EVENTS },
-	199520639 => { BS => $NO_EVENTS },
-	199520688 => { BS => $NO_EVENTS },
-	199520700 => { BS => $NO_EVENTS },
-	199520720 => { BS => $NO_EVENTS },
-	199520767 => { BS => $NO_EVENTS },
-	199520790 => { BS => $NO_EVENTS },
-	199520808 => { BS => $NO_EVENTS },
-	199520846 => { BS => $NO_EVENTS },
-	199520856 => { BS => $NO_EVENTS },
-	199520879 => { BS => $NO_EVENTS },
-	199520973 => { BS => $NO_EVENTS },
-	199530114 => { BS => $NO_EVENTS },
-	199530182 => { BS => $NO_EVENTS },
-	199620002 => { BS => $NO_EVENTS },
-	199620011 => { BS => $NO_EVENTS },
-	199620044 => { BS => $NO_EVENTS },
-	199620065 => { BS => $NO_EVENTS },
-	199620148 => { BS => $NO_EVENTS },
-	199620155 => { BS => $NO_EVENTS },
-	199620184 => { BS => $NO_EVENTS },
-	199620192 => { BS => $NO_EVENTS },
-	199620261 => { BS => $NO_EVENTS },
-	199620352 => { BS => $NO_EVENTS },
-	199620528 => { BS => $NO_EVENTS },
-	199620649 => { BS => $NO_EVENTS },
-	199620718 => { BS => $NO_EVENTS },
-	199620749 => { BS => $NO_EVENTS },
-	199620756 => { BS => $NO_EVENTS },
-	199620757 => { BS => $NO_EVENTS },
-	199620769 => { BS => $NO_EVENTS },
-	199620875 => { BS => $NO_EVENTS },
-	199620947 => { BS => $NO_EVENTS },
-	199621018 => { BS => $NO_EVENTS },
-	199621027 => { BS => $NO_EVENTS },
-	199621039 => { BS => $NO_EVENTS },
-	199621048 => { BS => $NO_EVENTS },
-	199621058 => { BS => $NO_EVENTS },
-	199630153 => { BS => $NO_EVENTS },
-	199630182 => { BS => $NO_EVENTS },
-	199630233 => { BS => $NO_EVENTS },
-	199720005 => { BS => $NO_EVENTS },
-	199720011 => { BS => $NO_EVENTS },
-	199720058 => { BS => $NO_EVENTS },
-	199720066 => { BS => $NO_EVENTS },
-	199720087 => { BS => $NO_EVENTS },
-	199720173 => { BS => $NO_EVENTS },
-	199720358 => { BS => $NO_EVENTS },
-	199720379 => { BS => $NO_EVENTS },
-	199720384 => { BS => $NO_EVENTS },
-	199720462 => { BS => $NO_EVENTS },
-	199720508 => { BS => $NO_EVENTS },
-	199720514 => { BS => $NO_EVENTS },
-	199720665 => { BS => $NO_EVENTS },
-	199720684 => { BS => $NO_EVENTS },
-	199720698 => { BS => $NO_EVENTS },
-	199720707 => { BS => $NO_EVENTS },
-	199720710 => { BS => $NO_EVENTS },
-	199720728 => { BS => $NO_EVENTS },
-	199720878 => { BS => $NO_EVENTS },
-	199720885 => { BS => $NO_EVENTS },
 	199720946 => { BS => $NO_EVENTS },
-	199720947 => { BS => $NO_EVENTS },
-	199820068 => { BS => $NO_EVENTS },
-	199820080 => { BS => $NO_EVENTS },
-	199820123 => { BS => $NO_EVENTS },
-	199820137 => { BS => $NO_EVENTS },
-	199820177 => { BS => $NO_EVENTS },
-	199820227 => { BS => $NO_EVENTS },
-	199820237 => { BS => $NO_EVENTS },
-	199820277 => { BS => $NO_EVENTS },
-	199820283 => { BS => $NO_EVENTS },
-	199820296 => { BS => $NO_EVENTS },
-	199820298 => { BS => $NO_EVENTS },
-	199820476 => { BS => $NO_EVENTS },
-	199820542 => { BS => $NO_EVENTS },
-	199820692 => { BS => $NO_EVENTS },
-	199820760 => { BS => $NO_EVENTS },
-	199820905 => { BS => $NO_EVENTS },
-	199821013 => { BS => $NO_EVENTS },
-	199821028 => { BS => $NO_EVENTS },
-	199821031 => { BS => $NO_EVENTS },
-	199821054 => { BS => $NO_EVENTS },
-	199821066 => { BS => $NO_EVENTS },
-	199830121 => { BS => $NO_EVENTS },
-	199830146 => { BS => $NO_EVENTS },
-	199920016 => { BS => $NO_EVENTS },
 	199920029 => { ES => $REPLICA, GS => $REPLICA },
 	199920045 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	199920050 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	199920058 => { ES => $REPLICA, GS => $REPLICA },
 	199920071 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	199920072 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
-	199920081 => { BS => $NO_EVENTS, ES => $INCOMPLETE, GS => $INCOMPLETE },
+	199920081 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	199920109 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	199920130 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
-	199920323 => { BS => $NO_EVENTS, ES => $REPLICA, GS => $REPLICA },
+	199920323 => { ES => $REPLICA, GS => $REPLICA },
 	199920619 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	199920689 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	199920690 => { ES => $BROKEN, GS => $INCOMPLETE },
@@ -972,7 +389,7 @@ our %BROKEN_FILES = (
 	200020041 => { ES => $REPLICA, GS => $REPLICA },
 	200020042 => { ES => $REPLICA, GS => $REPLICA },
 	200020043 => { ES => $REPLICA, GS => $REPLICA },
-	200020044 => { BS => $NO_EVENTS, ES => $REPLICA, GS => $REPLICA },
+	200020044 => { ES => $REPLICA, GS => $REPLICA },
 	200020045 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	200020049 => { ES => $REPLICA, GS => $REPLICA },
 	200020067 => { ES => $REPLICA, GS => $REPLICA },
@@ -1003,8 +420,14 @@ our %BROKEN_FILES = (
 	200021166 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	200021167 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
 	200021171 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
+	200120012 => { BS => $NO_EVENTS },
+	200120974 => { BS => $NO_EVENTS },
+	200220396 => { BS => $NO_EVENTS },
+	200220414 => { BS => $NO_EVENTS },
+	200220645 => { BS => $NO_EVENTS },
 	200220916 => { PL => $INCOMPLETE },
 	200320191 => { GS => $INCOMPLETE },
+	200320257 => { BS => $NO_EVENTS },
 	200321205 => { ES => $INCOMPLETE, GS => $INCOMPLETE, PL => $INCOMPLETE },
 	200330134 => { PL => $BROKEN },
 	200520298 => { ES => $REPLICA },
@@ -1014,6 +437,7 @@ our %BROKEN_FILES = (
 	200520681 => { RO => $BROKEN },
 	200621024 => { ES => $INCOMPLETE, GS => $INCOMPLETE, PL => $BROKEN, },
 	200621024 => { ES => $INCOMPLETE, GS => $INCOMPLETE, PL => $BROKEN, },
+	200720262 => { BS => $NO_EVENTS, },
 	200720470 => { GS => $INCOMPLETE, },
 	200720483 => { GS => $INCOMPLETE, },
 	200721178 => { ES => $INCOMPLETE, GS => $INCOMPLETE, PL => $BROKEN, RO => $INCOMPLETE },
@@ -1028,14 +452,18 @@ our %BROKEN_FILES = (
 	200920874 => { ES => $INCOMPLETE, GS => $INCOMPLETE, RO => $INCOMPLETE },
 	200920885 => { ES => $INCOMPLETE, RO => $INCOMPLETE },
 	201020429 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
+	201020575 => { BS => $NO_EVENTS },
+	201020704 => { BS => $NO_EVENTS },
 	201120259 => { ES => $INCOMPLETE, GS => $INCOMPLETE },
+	201320338 => { BS => $NO_EVENTS },
 	201320971 => { GS => $BROKEN },
 	201520079 => {BH => $INCOMPLETE},
 	201520120 => {BH => $INCOMPLETE},
 	201520168 => {BH => $INCOMPLETE},
 	201520214 => {BH => $INCOMPLETE},
 	201520307 => {BH => $INCOMPLETE},
-#	201720620 => {PL => $INCOMPLETE, RO => $INCOMPLETE, ES => $INCOMPLETE},
+	201520476 => { BS => $NO_EVENTS },
+	201720639 => { BS => $NO_EVENTS },
 );
 
 our %MANUAL_FIX = (
